diff -upr geany-orig/src/build.c geany/src/build.c
--- geany-orig/src/build.c	2006-12-18 07:10:27.000000000 -0500
+++ geany/src/build.c	2006-12-28 11:12:33.000000000 -0500
@@ -685,7 +685,7 @@ static gboolean build_iofunc(GIOChannel 
 	if (cond & (G_IO_IN | G_IO_PRI))
 	{
 		//GIOStatus s;
-		gchar *msg;
+		gchar *msg, *dir = NULL;
 
 		while (g_io_channel_read_line(ioc, &msg, NULL, NULL, NULL) && msg)
 		{
@@ -693,12 +693,19 @@ static gboolean build_iofunc(GIOChannel 
 			gint color;
 			color = (GPOINTER_TO_INT(data)) ? COLOR_DARK_RED : COLOR_BLACK;
 			g_strstrip(msg);
-
+			
+			if (strstr(msg, "Entering directory") != NULL) {
+				if (dir != NULL)
+					g_free(dir);
+				parse_string_for_dir(msg, &dir);
+			}			
+			
 			if (app->pref_editor_use_indicators)
 			{
 				gchar *filename;
 				gint line;
-				msgwin_parse_compiler_error_line(msg, &filename, &line);
+				
+				msgwin_parse_compiler_error_line(msg, dir, &filename, &line);
 				if (line != -1 && filename != NULL)
 				{
 					gint idx = document_find_by_filename(filename, FALSE);
@@ -711,6 +718,9 @@ static gboolean build_iofunc(GIOChannel 
 
 			g_free(msg);
 		}
+		
+		if (dir != NULL)
+			g_free(dir);
 	}
 	if (cond & (G_IO_ERR | G_IO_HUP | G_IO_NVAL))
 		return FALSE;
diff -upr geany-orig/src/msgwindow.c geany/src/msgwindow.c
--- geany-orig/src/msgwindow.c	2006-12-18 07:10:27.000000000 -0500
+++ geany/src/msgwindow.c	2006-12-28 11:40:04.000000000 -0500
@@ -415,6 +415,66 @@ void msgwin_menu_add_common_items(GtkMen
 		G_CALLBACK(on_hide_message_window), NULL);
 }
 
+gboolean parse_string_for_dir(gchar *string, gchar **prefix)
+{
+	gchar *pos, *input;
+	
+	input = g_strdup(string);
+	if (input == NULL)
+		return FALSE;
+	
+	*prefix = NULL;
+	
+	if ((pos = strstr(input, "Entering directory")) != NULL)
+	{
+		gsize len = strlen(input);
+		
+		//get the start of the path
+		pos = strstr(input, "/");
+		
+		if (pos == NULL) {
+			g_free(input);
+			return FALSE;
+		}
+		
+		//kill the ' at the end of the path
+		input[len-1] = '\0';
+		
+		//duplicate
+		*prefix = g_strdup(pos);
+		
+		g_free(input);
+		return TRUE;
+	}
+	
+	g_free(input);
+	return FALSE;
+}
+
+/* look back up from the current path and find the directory we came from */
+static gboolean 
+msgwin_get_file_path(GtkTreePath *cur, GtkTreeModel *model, gchar **prefix)
+{
+	GtkTreeIter iter;
+	*prefix = NULL;
+	
+	while (gtk_tree_path_prev(cur))
+	{
+		if (gtk_tree_model_get_iter(model, &iter, cur))
+		{
+			gchar *string;
+			gtk_tree_model_get(model, &iter, 1, &string, -1);
+			if (string != NULL && parse_string_for_dir(string, prefix))
+			{
+				g_free(string);
+				return TRUE;
+			}
+			g_free(string);
+		}
+	}
+	
+	return FALSE;
+}
 
 gboolean msgwin_goto_compiler_file_line()
 {
@@ -442,8 +502,14 @@ gboolean msgwin_goto_compiler_file_line(
 		{
 			gint line;
 			gint idx;
-			gchar *filename;
-			msgwin_parse_compiler_error_line(string, &filename, &line);
+			gchar *filename, *dir;
+			
+			msgwin_get_file_path(gtk_tree_model_get_path(model, &iter), model, &dir);
+			msgwin_parse_compiler_error_line(string, dir, &filename, &line);
+			
+			if (dir != NULL)
+				g_free(dir);
+			
 			if (filename != NULL && line > -1)
 			{
 				gchar *utf8_filename = utils_get_utf8_from_locale(filename);
@@ -533,14 +599,17 @@ static void parse_file_line(ParseData *d
  * relevant file with the error in *filename.
  * *line will be -1 if no error was found in string.
  * *filename must be freed unless it is NULL. */
-void msgwin_parse_compiler_error_line(const gchar *string, gchar **filename, gint *line)
+void msgwin_parse_compiler_error_line(const gchar *string, const gchar *dir, gchar **filename, gint *line)
 {
 	ParseData data = {string, build_info.dir, NULL, 0, 0, 0};
 
 	*filename = NULL;
 	*line = -1;
 
-	g_return_if_fail(build_info.dir != NULL);
+	if (dir != NULL)
+		data.dir = dir;
+
+	g_return_if_fail(build_info.dir != NULL || dir != NULL);
 	if (string == NULL) return;
 
 	switch (build_info.file_type_id)
diff -upr geany-orig/src/msgwindow.h geany/src/msgwindow.h
--- geany-orig/src/msgwindow.h	2006-12-18 07:10:27.000000000 -0500
+++ geany/src/msgwindow.h	2006-12-28 08:06:43.000000000 -0500
@@ -79,8 +79,10 @@ void msgwin_menu_add_common_items(GtkMen
 
 gboolean msgwin_goto_compiler_file_line();
 
-void msgwin_parse_compiler_error_line(const gchar *string, gchar **filename, gint *line);
+void msgwin_parse_compiler_error_line(const gchar *string, const gchar *dir, gchar **filename, gint *line);
 
 gboolean msgwin_goto_messages_file_line();
 
+gboolean parse_string_for_dir(gchar *input, gchar **prefix);
+
 #endif